function f = dXdT1(~,x,par1,par2,Qin)

alpha1  = par1(1);
alpha2  = par1(2);
alpha3  = par1(3);
alpha4  = par1(4);
tau_AR  = par1(5);
tau_R   = par1(6);
tau_A2  = par1(7);
Pra2    = par1(8);
Pra1    = par1(9);

F0      = par2(1);
F1      = par2(2);
Vv01    = par2(3);

% Systemic resistances and compliances
RA0 = 0.0661 / ((1+alpha2*0.25)*(1+alpha4*0.1857)) / ((tanh((1500-F0)/F1)+1)/2);
RV0 = 0.00033585;
CA0 = 0.63568 * ((1+alpha1*0.25)*(1+alpha3*0.1857));

% Aorta mechanics parameters
tau_ca  = 0.12/60;
CAo = 0.0070;
gamma_a = 0.40;
L = 30; % mm
D0 = 12;
V0 = (1e-3)*L*D0^2 / (2*pi);
% Baroreflex model parameters
tau_str = 251.525/60;
a       = 0.0651*60;
b       = 0.2004*60;
st0     = 0.4965;
f0      = 299.7511;
% SN tone parameters
fSN = 2.76;
% RA system
g       = 4*(100-Pra1-0.737*Pra2);
% Urine parameters
k1 = 0.125;
Ps_max = 126.4250;
Ps_min = 9.7788;
phi0   = 0.1928;
phi1   = 0.4813;
% Other parameters
Rout   = 0.0001;
RAo    = 0.0003;
tau_c1 = 2;
gamma1 = 0.4;
CV0 = (1287 - Vv01)*(1-gamma1)/1.55 * ((1+alpha1*0.25)*(1+alpha3*0.1857));

V_lv   = x(1);
V_Ao   = x(2);
V_A    = x(3);
V_V    = x(4);
Vsa    = x(5);
Vsv    = x(6);
Ps     = x(7);
s1     = x(8);
st_m   = x(9);
phi_SN = x(10);
Theta  = x(11);
Pave   = x(12);
Fave   = x(13);
phi_R  = x(14);
phi_A2 = x(15);
R_AR   = x(16);

% Circuit model calculations
CA = CA0 / ((1+alpha1*phi_SN)*(1+alpha3*phi_A2));
CV = CV0 / ((1+alpha1*phi_SN)*(1+alpha3*phi_A2));
RA = RA0 * ((1+alpha2*phi_SN)*(1+alpha4*phi_A2));
RV = RV0;
P_Ao = (V_Ao-Vsa)/CAo;
P_A  = (V_A)/CA;
P_V  = (V_V-Vsv-Vv01)/CV;
ep = 1 + 1*(phi_SN - 0.25);
H  = 75 + 100*(phi_SN - 0.25);
P_lv = PVfunction(Theta,V_lv,ep);
F_out = max(0, (P_lv-P_Ao)/Rout);
F_in  = max(0, (P_V-P_lv)/RV);
% Vascular mechanics
str = sqrt(V_Ao/V0);
Vsa_inf = gamma_a*V_Ao;
V_sv_inf = gamma1*(V_V - Vv01);
% Autoregulation
R_AR_inf = (tanh((Fave-F0)/F1)+1)/2;
% Renal model
Ps_inf = Ps_min + ((Ps_max - Ps_min)/2)*(tanh((phi_SN+phi_A2-phi0)/phi1)+1);
Qurine = max(0,min( k1*(Pave-Ps),10 ));
% Sympathetic tone and cardiac pumping
dstr = max(0,str-st_m);
f_BR = f0*s1*dstr./(dstr+st0);
% R-A system
phi_R_inf = (1-tanh((Pave-g*phi_SN-Pra1)/Pra2))/2;

f(1,:)  = F_in - F_out;                                 % (1) V_lv
f(2,:)  = F_out - (P_Ao - P_A)/RAo;                     % (2) V_Ao
f(3,:)  = (P_Ao - P_A)/RAo - (P_A - P_V)/(RA*R_AR);     % (3) V_A
f(4,:)  = (P_A - P_V)/(RA*R_AR) - F_in + Qin - Qurine;  % (4) V_V
f(5,:)  = (Vsa_inf - Vsa)/tau_ca;                       % (5) Vsa
f(6,:)  = (V_sv_inf - Vsv)/tau_c1;                      % (6) Vsv
f(7,:)  = (Ps_inf - Ps)/10;                             % (7) Ps
f(8,:)  = +a*(1-s1) - b*dstr/(dstr + st0)*s1;           % (8) s1
f(9,:)  = (str - st_m) / tau_str;                       % (9) str_m
f(10,:) = fSN*(1-phi_SN) - f_BR*phi_SN;                 % (10) phi_SN
f(11,:) = H;                                            % (11) Theta
f(12,:) = (P_A - Pave)/0.25;                            % (12) Pave
f(13,:) = ((P_A - P_V)/(RA*R_AR) - Fave)/0.25;          % (13) Fave
f(14,:) = (phi_R_inf-phi_R)/tau_R;                      % (14) phi_R
f(15,:) = (phi_R-phi_A2)/tau_A2;                        % (15) phi_A2
f(16,:) = (R_AR_inf-R_AR)/tau_AR;                       % (16) R_AR
